@@ -38,3 +38,9 @@ ACC_COMPONENTS_ELECTRICITY = [
     "methane_leakage",
 ]
 ACC_COMPONENTS_GAS = ["market", "t_d", "environment", "upstream_methane", "total"]
+
+THERMS_PROFILE_ADJUSTMENT = {
+    "PGE": {"annual": 0.9427, "summer": 0.8293, "winter": 1.0558},
+    "SCE": {"annual": 0.8948, "summer": 0.8282, "winter": 0.9611},
+    "SDGE": {"annual": 0.9435, "summer": 0.8394, "winter": 1.0469},
+}
